from .wog_abs import WoG
from .utils import number_to_game, is_digit
import random


class GuessGame(WoG):

    def __init__(self, user_name, difficulty, game):
        self.name = user_name
        self.level = difficulty
        self.game = game
        return

    secret_number = 0
    data_num_from_user = 0

    def print_data(self):
        print(f'GuessGame: {self.name} choose to play "{number_to_game[self.game]}" '
              f'with difficulty level of {self.level}.')

    @property
    def short_explanation_before_the_game(self):
        print(f'Starting to play Guess Game.... ')
        print(f'The purpose is to guess the number the computer chose. ')
        print(f' ******************************************************')
        print(f' * Important: chose only numbers in range "1" to "{self.level}". *')
        print(f' ******************************************************')
        print(f'\n')

    @property
    def generate_number(self):
        self.secret_number = random.randint(1, self.level)
        # print(f'secret_number = {self.secret_number}')

    def get_guess_from_user(self):
        data_num = input(f'Guess number between 1 to {self.level}: ')
        if not is_digit(data_num):
            print(f'You typed not valid number: "{data_num}"!! Need to type only number.')
            print(f'Game Over for you :( ')
            return False
        # print('data_num: ', data_num)
        # print(type(data_num))
        self.data_num_from_user = int(data_num)
        if self.data_num_from_user not in range(1,self.level):
            print(f'You typed number not in range "1" to "{self.level}"!! Need to type only number in that range.')
            print(f'Game Over for you :( ')
            return False
        return True

    @property
    def compare_data(self):
        # print(f'compare: {self.secret_number}, {self.data_num_from_user}')
        if self.data_num_from_user == self.secret_number:
            return True
        else:
            return False

    @property
    def play(self):
        self.short_explanation_before_the_game
        self.generate_number
        n = input('press any key when you will ready to start.\nTo quit press "q". ')
        if n == 'q':
            print(f'You choose to quit game ... ')
            return False
        if not self.get_guess_from_user():
            return False
        if self.compare_data:
            print(f'Good job {self.name}, you managed to guess the number :)')
            return True
        else:
            print(f'{self.name}, you did not manage to guess the number. The secret number was {self.secret_number}')
            return False




from .wog_abs import WoG
import random
from .utils import number_to_game, is_digit
import currency_converter
from currency_converter import CurrencyConverter


class CurrencyRGame(WoG):

    def __init__(self, user_name, difficulty, game):
        self.name = user_name
        self.level = difficulty
        self.game = game
        return

    usd_number = 0  # between 1-100 for user to guess
    total_value_of_money = 0
    current_currency_rate = 0
    start_interval = 0
    end_interval = 0
    user_guess = 0
    dolarToNis = 0

    def print_data(self):
        print(f'CurrencyRGame: {self.name} choose to play "{number_to_game[self.game]}" '
              f'with difficulty level of {self.level}.')

    @property
    def short_explanation_before_the_game(self):
        print(f'Starting to play Currency Roulette Game.... ')
        print(f'The purpose is to guess how match US$ is in ILS.')
        print(f' *********************************')
        print(f' * Important: type only numbers. *')
        print(f' *********************************')
        print(f'\n')

    @property
    def generated_number(self):
        number = random.randint(1, 100)
        self.usd_number = number

    @property
    def generated_number_from_USD_to_ILS(self):
        c = CurrencyConverter()
        self.dolarToNis = c.convert(1, 'USD', 'ILS')
        self.dolarToNis = float(format(self.dolarToNis, '.2f'))
        self.current_currency_rate = self.usd_number * self.dolarToNis

    @property
    def delta_to_check(self, number_to_check):
        start_range = (self.usd_number - (5 - self.level))
        end_range = (self.usd_number - (5 + self.level))
        if number_to_check not in range(start_range, end_range):
            return False
        else:
            return True

    def get_guess_from_user(self):
        guess = input(f'Enter a guess of ILS value for {self.usd_number}$ :')
        if not is_digit(guess):
            print(f'You typed not valid number: "{guess}"!! Need to type only number.')
            print(f'Game Over for you :( ')
            return False
        self.user_guess = float(guess)
        return True

    @property
    def calc_range(self):
        i_range = 5 - self.level
        # print(f'tmp={tmp}, level={self.level}')
        self.start_interval = ((self.usd_number - i_range) * self.dolarToNis)
        # print(f'self.start_interval: {self.start_interval}, self.end_interval {self.end_interval}')
        self.end_interval = ((self.usd_number + i_range) * self.dolarToNis)
        # print(f'self.start_interval: {self.start_interval}, self.end_interval {self.end_interval}')

    @property
    def compare_data(self):
        # print(f'compare: {type(self.user_guess)}, {self.current_currency_rate}')
        # print(f'self.start_interval: {self.start_interval}, self.end_interval {self.end_interval}')
        # print(f'self.start_interval: {type(self.start_interval)}, self.end_interval {type(self.end_interval)}')
        if self.start_interval <= self.user_guess <= self.end_interval:
            print(f'The number {self.user_guess} is in range ({self.start_interval} - {self.end_interval})')
            return True
        else:
            print(f'The number {self.user_guess} is not in range ({self.start_interval} - {self.end_interval})')
            return False

    @property
    def play(self):
        self.short_explanation_before_the_game
        self.generated_number
        self.generated_number_from_USD_to_ILS
        # print(f'self.dolarToNis={self.dolarToNis}, current_currency_rate={self.current_currency_rate}')
        n = input('press any key when you will ready to start.\nTo quit press "q". ')
        if n == 'q':
            print(f'You choose to quit game ... ')
            return False
        if not self.get_guess_from_user():
            return False
        self.calc_range
        if self.compare_data:
            print(f'Good !! manage to guessed "how match is {self.usd_number}$ in ILS."')
            return True
        else:
            print(f'Not bad, next time you might succeed.\n'
                  f'The correct answer is: {self.usd_number}$ is {self.current_currency_rate}Nis')
            return False





from .utils import get_user_name, welcome, load_game, number_to_game ,is_digit
from .Factory import Factory
from .wog_abs import WoG
from .MemoryGame import MemoryGame
from .GuessGame import GuessGame
from .CurrencyRGame import CurrencyRGame
from currency_converter import CurrencyConverter
#__all__ = ['get_user_name', 'Factory', 'GuessGame', 'mainGame',
#           'MemoryGame', 'utils', 'wog_abs']

#from .__main__ import main
#import mainGame
#from setuptools import setup, find_packages

#setup(
#    name='wog_pkg',
#      version='0.2.0',
#      description='World of Games'N,
#      long_description=(HERE / "README.txt").read_text(),
#      #long_description_content_type=LONG_DESC_TYPE,
#      author='Oren Jacobovitz',
#      license='Apache License 2.0',
#      author_email='oj.gmbox@gmail.com',
#      #url=URL,
#      #install_requires=INSTALL_REQUIRES,
#      packages=find_packages()
#)


import pathlib
from setuptools import setup, find_packages

HERE = pathlib.Path(__file__).parent

README = (HERE / "README.md").read_text()

VERSION = '1.1.60'
PACKAGE_NAME = 'wogDev'
AUTHOR = 'Oren Jacobovitz'
AUTHOR_EMAIL = 'oj.gmbox@gmail.com'
#URL = 'https://github.com/you/your_package'

LICENSE = 'Apache License 2.0'
DESCRIPTION = 'World of Games'
LONG_DESC_TYPE = "text/markdown"

INSTALL_REQUIRES = [
      'currency_converter',
      'abc',
      'random',
      'time',
      'os',
      'collections'
]
 
setup(name=PACKAGE_NAME,
      version=VERSION,
      description=DESCRIPTION,
      long_description=README,
      #long_description_content_type=LONG_DESC_TYPE,
      author=AUTHOR,
      license=LICENSE,
      author_email=AUTHOR_EMAIL,
      #packages=["wog_pkg"],
      #packages=find_packages(),
      #include_package_data=True
      #entry_points={
       #       "console_scripts": [
       #     "realpython=reader.__main__:main",
       #     ]
       # },
      #url=URL,
      install_requires=INSTALL_REQUIRES,
      packages=find_packages()
)


import utils
from .utils import get_user_name, welcome, load_game, number_to_game
from .Factory import Factory


def main():
    user_name = get_user_name()
    welcome(user_name)
    game, level = load_game()
    obj_game = Factory.create_game(number_to_game[game], user_name, level, game)
    obj_game.print_data()
    obj_game.play


if __name__ == '__main__':
    main()
